@@ -2,18 +2,18 @@ import sys
 import platform
 import urllib
 import urllib2
-import httplib
 import base64
 import gzip
+import os
 from StringIO import StringIO
 from urlparse import urlparse
 try:
   import json
 except ImportError:
   import simplejson as json
-from utils import json_to_py, get_faker
+from utils import VerifiedHTTPSConnection, json_to_py, get_faker
 
-__version_info__ = ('3', '2', '0')
+__version_info__ = ('3', '3', '0')
 __version__ = '.'.join(__version_info__)
 
 class CreateSendError(Exception):
@@ -156,7 +156,7 @@ class CreateSendBase(object):
       status = self.faker.status if (self.faker and self.faker.status) else 200
       return self.handle_response(status, data)
 
-    c = httplib.HTTPConnection(parsed_base_uri.netloc)
+    c = VerifiedHTTPSConnection(parsed_base_uri.netloc)
     c.request(method, self.build_url(parsed_base_uri, path, params), body, headers)
     response = c.getresponse()
     if response.getheader('content-encoding', '') == 'gzip':
